.. _installation:

Installation
======================

Via Python Package Index
------------------------

Install the latest version from PyPI:

.. code-block:: console

    pip install rgwadmin


Via Source
----------

The project is hosted at https://github.com/UMIACS/rgwadmin and can be installed
using git:

.. code-block:: console

    git clone https://github.com/umiacs/rgwadmin.git
    cd rgwadmin
    python setup.py install
